@@ -4,6 +4,8 @@ REES = ["SUDESTE", "SUL", "NORDESTE", "NORTE",
         "MAN-AP", "PARANA", "IGUACU", "PRNPANEMA"]
 MAX_SEMANAS_PRE = 10
 MAX_ESTAGIOS = 10
+MAX_SUBSISTEMAS = 10
+MAX_REES = 20
 MESES = ["JANEIRO",
          "FEVEREIRO",
          "MARCO",
