@@ -1,6 +1,6 @@
 # Imports do próprio módulo
-from idecomp.config import MAX_ESTAGIOS
-from idecomp.config import REES, SUBSISTEMAS
+from idecomp.config import MAX_ESTAGIOS, MAX_SUBSISTEMAS, MAX_REES
+from idecomp.config import SUBSISTEMAS
 from idecomp._utils.bloco import Bloco
 from idecomp._utils.registros import RegistroAn, RegistroFn, RegistroIn
 from idecomp._utils.leiturablocos import LeituraBlocos
@@ -10,6 +10,10 @@ import pandas as pd  # type: ignore
 from typing import IO, List
 
 
+# TODO - LER BLOCO DE ENA PREVISTA SEMANAL POR REE
+# TODO - LER BLOCO DE ENA PASSADA POR REE
+
+
 class BlocoDadosGeraisRelato(Bloco):
     """
     Bloco com as informações de eco dos dados gerais
@@ -118,8 +122,14 @@ class BlocoConvergenciaRelato(Bloco):
                 continue
             # Senão, lê mais uma linha
             tabela[i, 0] = reg_iter.le_registro(linha, 4)
-            tabela[i, 1] = reg_z.le_registro(linha, 9)
-            tabela[i, 2] = reg_z.le_registro(linha, 22)
+            if "*" in linha[9:21]:
+                tabela[i, 1] = np.nan
+            else:
+                tabela[i, 1] = reg_z.le_registro(linha, 9)
+            if "*" in linha[22:34]:
+                tabela[i, 2] = np.nan
+            else:
+                tabela[i, 2] = reg_z.le_registro(linha, 22)
             tabela[i, 3] = reg_gap.le_registro(linha, 35)
             tempo = reg_tempo.le_registro(linha, 52)
             parcelas = tempo.split(":")
@@ -298,7 +308,7 @@ class BlocoBalancoEnergeticoRelato(Bloco):
         subsis = "FC"
         subsistemas = []
         # Salta uma linha e extrai a semana
-        tabela = np.zeros((MAX_ESTAGIOS * len(SUBSISTEMAS), 11))
+        tabela = np.zeros((MAX_ESTAGIOS * MAX_SUBSISTEMAS, 11))
         i = 0
         while True:
             linha = arq.readline()
@@ -452,7 +462,7 @@ class BlocoGeracaoTermicaSubsistemaRelato(Bloco):
         reg_gt = RegistroFn(10)
         n_semanas = len(sems)
         subsistemas: List[str] = []
-        tabela = np.zeros((len(SUBSISTEMAS),
+        tabela = np.zeros((MAX_SUBSISTEMAS,
                            n_semanas))
         # Salta outra linha
         arq.readline()
@@ -461,6 +471,7 @@ class BlocoGeracaoTermicaSubsistemaRelato(Bloco):
             # Confere se a leitura não acabou
             linha = arq.readline()
             if "X------X" in linha:
+                tabela = tabela[:i, :]
                 self._dados = converte_tabela_em_df()
                 break
             # Senão, lê mais uma linha
@@ -558,6 +569,326 @@ class BlocoVolumeUtilReservatorioRelato(Bloco):
         pass
 
 
+class BlocoDadosTermicasRelato(Bloco):
+    """
+    Bloco com as informações de cadastro das térmicas existentes no estudo.
+    """
+    str_inicio = "Relatorio  dos  Dados  de  Usinas  Termicas"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoDadosTermicasRelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoDadosTermicasRelato):
+            return False
+        bloco: BlocoDadosTermicasRelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            cols = ["GT Min Pat. 1", "GT Max Pat. 1", "Custo Pat. 1",
+                    "GT Min Pat. 2", "GT Max Pat. 2", "Custo Pat. 2",
+                    "GT Min Pat. 3", "GT Max Pat. 3", "Custo Pat. 3"]
+            df = pd.DataFrame(tabela, columns=cols)
+            df["Código"] = numeros
+            df["Usina"] = usinas
+            df["Subsistema"] = subsistemas
+            df["Estágio"] = estagios
+            df = df[["Código", "Usina", "Subsistema", "Estágio"] + cols]
+            return df
+
+        # Salta as linhas de cabeçalho
+        for _ in range(4):
+            arq.readline()
+
+        reg_num = RegistroIn(3)
+        reg_usina = RegistroAn(10)
+        reg_subsis = RegistroAn(6)
+        reg_estagio = RegistroIn(7)
+        reg_valores = RegistroFn(7)
+        numeros: List[int] = []
+        usinas: List[str] = []
+        subsistemas: List[str] = []
+        estagios: List[int] = []
+
+        tabela = np.zeros((5000, 9))
+
+        i = 0
+        num_atual = 0
+        usina_atual = ""
+        subsis_atual = ""
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X---X----------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            # Verifica se começa uma nova UTE na linha
+            if len(linha[4:7].strip()) > 0:
+                num_atual = reg_num.le_registro(linha, 4)
+                usina_atual = reg_usina.le_registro(linha, 8)
+                subsis_atual = reg_subsis.le_registro(linha, 19)
+            # Lê as propriedades existentes em todas as linhas
+            numeros.append(num_atual)
+            usinas.append(usina_atual)
+            subsistemas.append(subsis_atual)
+            estagios.append(reg_estagio.le_registro(linha, 26))
+            tabela[i, :] = reg_valores.le_linha_tabela(linha, 34, 1, 9)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoDisponibilidadesTermicasRelato(Bloco):
+    """
+    Bloco com as informações de disponibilidade
+    das térmicas existentes no estudo.
+    """
+    str_inicio = "Disponibilidade das Usinas Termicas (%)"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoDisponibilidadesTermicasRelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoDisponibilidadesTermicasRelato):
+            return False
+        bloco: BlocoDisponibilidadesTermicasRelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            cols = [f"Estágio {i}" for i in range(1, n_semanas + 1)]
+            df = pd.DataFrame(tabela, columns=cols)
+            df["Código"] = numeros
+            df["Usina"] = usinas
+            df = df[["Código", "Usina"] + cols]
+            return df
+
+        # Salta uma linha
+        arq.readline()
+
+        # Descobre o número de estágios
+        linha = arq.readline()
+        sems = [s for s in linha.split(" ") if (len(s) > 0
+                                                and ("Sem" in s or
+                                                     "Mes" in s))]
+        n_semanas = len(sems)
+
+        reg_num = RegistroIn(3)
+        reg_usina = RegistroAn(12)
+        reg_valores = RegistroFn(6)
+        numeros: List[int] = []
+        usinas: List[str] = []
+        tabela = np.zeros((300, n_semanas))
+
+        # Salta outra linha
+        arq.readline()
+        i = 0
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X---X------------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            numeros.append(reg_num.le_registro(linha, 4))
+            usinas.append(reg_usina.le_registro(linha, 8))
+            tabela[i, :] = reg_valores.le_linha_tabela(linha,
+                                                       21,
+                                                       1,
+                                                       n_semanas)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoDadosMercadoRelato(Bloco):
+    """
+    Bloco com as informações de mercado de energia por patamar
+    e por subsistema existente no :class:`Relato`.
+    """
+    str_inicio = "Relatorio  dos  Dados  de  Mercado"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoDadosMercadoRelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoDadosMercadoRelato):
+            return False
+        bloco: BlocoDadosMercadoRelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            cols = ["Patamar 1", "Mercado 1",
+                    "Patamar 2", "Mercado 2",
+                    "Patamar 3", "Mercado 3"]
+            df = pd.DataFrame(tabela, columns=cols)
+            df["Estágio"] = estagios
+            df["Subsistema"] = subsistemas
+            df = df[["Estágio", "Subsistema"] + cols]
+            return df
+
+        # Salta as linhas de cabeçalho
+        for _ in range(4):
+            arq.readline()
+
+        reg_estagio = RegistroIn(9)
+        reg_subsis = RegistroAn(6)
+        reg_valores = RegistroFn(9)
+        estagios: List[int] = []
+        subsistemas: List[str] = []
+
+        tabela = np.zeros((100, 6))
+
+        i = 0
+        estagio_atual = 0
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X---------X------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            # Verifica se começa um novo estágio na linha
+            if len(linha[4:13].strip()) > 0:
+                estagio_atual = reg_estagio.le_registro(linha, 4)
+            # Lê as propriedades existentes em todas as linhas
+            estagios.append(estagio_atual)
+            subsistemas.append(reg_subsis.le_registro(linha, 14))
+            tabela[i, :] = reg_valores.le_linha_tabela(linha, 21, 1, 6)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoENAAcoplamentoREERelato(Bloco):
+    """
+    Bloco com as informações de energia natural afluente para
+    acoplamento com o longo prazo por REE.
+    """
+    str_inicio = "Afluente para Acoplamento c/ Longo Prazo por REE"
+    str_fim = "Afluente para Acoplamento c/ Longo Prazo por Subsistema"
+
+    def __init__(self):
+
+        super().__init__(BlocoENAAcoplamentoREERelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados: pd.DataFrame = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoENAAcoplamentoREERelato):
+            return False
+        bloco: BlocoENAAcoplamentoREERelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def le_tabela(linha: str) -> np.ndarray:
+            indice_ree = int(linha.split("REE: ")[1].split("-")[0].strip())
+            ree = linha.split("REE: ")[1].split("/")[0].split("-")[1].strip()
+            subsis = linha.split("SUBSISTEMA: ")[1].split("-")[1].strip()
+            # Salta uma linha para identificar o número de estágios
+            arq.readline()
+            lin = arq.readline()
+            sems = [s for s in lin.split(" ") if (len(s) > 0
+                                                  and ("Sem" in s or
+                                                       "Mes" in s))]
+            n_semanas = len(sems)
+            arq.readline()
+            # Começa a ler os cenários
+            reg_cen = RegistroIn(3)
+            reg_ena = RegistroFn(8)
+            tab = np.zeros((1000, n_semanas + 1))
+            i = 0
+            while True:
+                lin = arq.readline()
+                if len(lin) < 4:
+                    tab = tab[:i, :]
+                    break
+                tab[i, 0] = reg_cen.le_registro(lin, 4)
+                tab[i, 1:] = reg_ena.le_linha_tabela(lin, 8, 1, n_semanas)
+                indices_rees.append(indice_ree)
+                rees.append(ree)
+                subsistemas.append(subsis)
+                i += 1
+            return tab
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            if isinstance(tabela, np.ndarray):
+                df = pd.DataFrame(tabela)
+                n_semanas = tabela.shape[1] - 1
+            else:
+                raise TypeError("Erro na leitura das ENAs para acoplamento")
+            cols = ["Cenário"] + [f"Estágio {s}"
+                                  for s in range(1, n_semanas + 1)]
+            df.columns = cols
+            df["Índice"] = indices_rees
+            df["REE"] = rees
+            df["Subsistema"] = subsistemas
+            df = df[["Índice", "REE", "Subsistema"] + cols]
+            df = df.astype({"Cenário": np.int64})
+            return df
+
+        indices_rees: List[int] = []
+        rees: List[str] = []
+        subsistemas: List[str] = []
+        tabela = None
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if BlocoENAAcoplamentoREERelato.str_fim in linha:
+                self._dados = converte_tabela_em_df()
+                return linha
+            if "REE: " in linha:
+                tab = le_tabela(linha)
+                if tabela is None:
+                    tabela = tab
+                else:
+                    tabela = np.vstack([tabela, tab])
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
 class BlocoEnergiaArmazenadaREERelato(Bloco):
     """
     Bloco com as informações de energia armazenada
@@ -604,8 +935,8 @@ class BlocoEnergiaArmazenadaREERelato(Bloco):
         reg_ssis = RegistroIn(4)
         n_semanas = len(sems)
         rees: List[str] = []
-        subsistemas: List[str] = []
-        tabela = np.zeros((len(REES),
+        subsistemas: List[int] = []
+        tabela = np.zeros((MAX_REES,
                            n_semanas + 1))
         # Salta outra linha
         arq.readline()
@@ -614,12 +945,13 @@ class BlocoEnergiaArmazenadaREERelato(Bloco):
             # Confere se a leitura não acabou
             linha = arq.readline()
             if "X------X" in linha:
+                tabela = tabela[:i, :]
                 self._dados = converte_tabela_em_df()
                 break
             # Senão, lê mais uma linha
             # Subsistema e REE
             ree = reg_ree.le_registro(linha, 4)
-            ssis = SUBSISTEMAS[reg_ssis.le_registro(linha, 22) - 1]
+            ssis = reg_ssis.le_registro(linha, 22) - 1
             rees.append(ree)
             subsistemas.append(ssis)
             # Semanas
@@ -684,7 +1016,7 @@ class BlocoEnergiaArmazenadaSubsistemaRelato(Bloco):
         reg_earm = RegistroFn(6)
         n_semanas = len(sems)
         subsistemas: List[str] = []
-        tabela = np.zeros((len(SUBSISTEMAS) - 1,
+        tabela = np.zeros((MAX_SUBSISTEMAS,
                            n_semanas + 1))
         # Salta outra linha
         arq.readline()
@@ -693,6 +1025,7 @@ class BlocoEnergiaArmazenadaSubsistemaRelato(Bloco):
             # Confere se a leitura não acabou
             linha = arq.readline()
             if "X------------X" in linha:
+                tabela = tabela[:i, :]
                 self._dados = converte_tabela_em_df()
                 break
             # Senão, lê mais uma linha
@@ -711,10 +1044,210 @@ class BlocoEnergiaArmazenadaSubsistemaRelato(Bloco):
         pass
 
 
+class BlocoENAPreEstudoMensalREERelato(Bloco):
+    """
+    Bloco com as informações da ENA pré estudo mensal do caso
+    por REE.
+    """
+    str_inicio = "ENERGIA NATURAL AFLUENTE POR REE (MESES"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoENAPreEstudoMensalREERelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoENAPreEstudoMensalREERelato):
+            return False
+        bloco: BlocoENAPreEstudoMensalREERelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            df = pd.DataFrame(tabela)
+            cols = ["Earmax"] + [f"Estágio Pré {s}"
+                                 for s in range(1, 12)]
+            df.columns = cols
+            df["REE"] = rees
+            df = df[["REE"] + cols]
+            return df
+
+        # Salta 4 linhas
+        for _ in range(4):
+            arq.readline()
+        reg_ree = RegistroAn(14)
+        reg_ena = RegistroFn(8)
+        rees: List[str] = []
+        tabela = np.zeros((20, 12))
+        i = 0
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X--------------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            # Subsistema e REE
+            ssis = reg_ree.le_registro(linha, 4)
+            rees.append(ssis)
+            # Semanas
+            tabela[i, :] = reg_ena.le_linha_tabela(linha,
+                                                   29,
+                                                   1,
+                                                   12)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoENAPreEstudoMensalSubsistemaRelato(Bloco):
+    """
+    Bloco com as informações da ENA pré estudo mensal do caso
+    por Subsistema.
+    """
+    str_inicio = "ENERGIA NATURAL AFLUENTE POR SUBSISTEMA (MESES"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoENAPreEstudoMensalSubsistemaRelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoENAPreEstudoMensalSubsistemaRelato):
+            return False
+        bloco: BlocoENAPreEstudoMensalSubsistemaRelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            df = pd.DataFrame(tabela)
+            cols = ["Earmax"] + [f"Estágio Pré {s}"
+                                 for s in range(1, 12)]
+            df.columns = cols
+            df["Subsistema"] = subsistemas
+            df = df[["Subsistema"] + cols]
+            return df
+
+        # Salta 4 linhas
+        for _ in range(4):
+            arq.readline()
+        reg_ssis = RegistroAn(14)
+        reg_ena = RegistroFn(8)
+        subsistemas: List[str] = []
+        tabela = np.zeros((MAX_SUBSISTEMAS,
+                           12))
+        i = 0
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X--------------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            # Subsistema e REE
+            ssis = reg_ssis.le_registro(linha, 4)
+            subsistemas.append(ssis)
+            # Semanas
+            tabela[i, :] = reg_ena.le_linha_tabela(linha,
+                                                   24,
+                                                   1,
+                                                   12)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
+class BlocoENAPreEstudoSemanalREERelato(Bloco):
+    """
+    Bloco com as informações da ENA pré estudo semanal do caso
+    por REE.
+    """
+    str_inicio = "DADOS DE ENERGIA NATURAL AFLUENTE POR REE (SEMANAS"
+    str_fim = ""
+
+    def __init__(self):
+
+        super().__init__(BlocoENAPreEstudoSemanalREERelato.str_inicio,
+                         "",
+                         True)
+
+        self._dados = pd.DataFrame()
+
+    def __eq__(self, o: object):
+        if not isinstance(o, BlocoENAPreEstudoSemanalREERelato):
+            return False
+        bloco: BlocoENAPreEstudoSemanalREERelato = o
+        return self._dados.equals(bloco._dados)
+
+    # Override
+    def le(self, arq: IO):
+
+        def converte_tabela_em_df() -> pd.DataFrame:
+            df = pd.DataFrame(tabela)
+            cols = ["Earmax"] + [f"Estágio Pré {s}"
+                                 for s in range(1, 6)]
+            df.columns = cols
+            df["REE"] = rees
+            df = df[["REE"] + cols]
+            # Remove as colunas preenchidas com 0
+            for c in cols:
+                if df[c].max() == 0:
+                    df.drop(columns=[c], inplace=True)
+            return df
+
+        # Salta 4 linhas
+        for _ in range(4):
+            arq.readline()
+        reg_ree = RegistroAn(14)
+        reg_ena = RegistroFn(8)
+        rees: List[str] = []
+        tabela = np.zeros((20, 6))
+        i = 0
+        while True:
+            # Confere se a leitura não acabou
+            linha = arq.readline()
+            if "X--------------X" in linha:
+                tabela = tabela[:i, :]
+                self._dados = converte_tabela_em_df()
+                break
+            # Senão, lê mais uma linha
+            # Subsistema e REE
+            ssis = reg_ree.le_registro(linha, 4)
+            rees.append(ssis)
+            # Semanas
+            tabela[i, :] = reg_ena.le_linha_tabela(linha,
+                                                   29,
+                                                   1,
+                                                   6)
+            i += 1
+
+    # Override
+    def escreve(self, arq: IO):
+        pass
+
+
 class BlocoENAPreEstudoSemanalSubsistemaRelato(Bloco):
     """
-    Bloco com as informações de eco dos dados gerais
-    utilizados na execução do caso.
+    Bloco com as informações da ENA pré estudo semanal do caso
+    por Subsistema.
     """
     str_inicio = "NATURAL AFLUENTE POR SUBSISTEMA(SEMANAS"
     str_fim = ""
@@ -743,6 +1276,10 @@ class BlocoENAPreEstudoSemanalSubsistemaRelato(Bloco):
             df.columns = cols
             df["Subsistema"] = subsistemas
             df = df[["Subsistema"] + cols]
+            # Remove as colunas preenchidas com 0
+            for c in cols:
+                if df[c].max() == 0:
+                    df.drop(columns=c, inplace=True)
             return df
 
         # Salta 4 linhas
@@ -751,13 +1288,14 @@ class BlocoENAPreEstudoSemanalSubsistemaRelato(Bloco):
         reg_ssis = RegistroAn(14)
         reg_ena = RegistroFn(8)
         subsistemas: List[str] = []
-        tabela = np.zeros((len(SUBSISTEMAS) - 1,
+        tabela = np.zeros((MAX_SUBSISTEMAS,
                            6))
         i = 0
         while True:
             # Confere se a leitura não acabou
             linha = arq.readline()
             if "X--------------X" in linha:
+                tabela = tabela[:i, :]
                 self._dados = converte_tabela_em_df()
                 break
             # Senão, lê mais uma linha
@@ -796,10 +1334,8 @@ class BlocoDiasExcluidosSemanas(Bloco):
         if not isinstance(o, BlocoDiasExcluidosSemanas):
             return False
         bloco: BlocoDiasExcluidosSemanas = o
-        return all([
-                    self._dados[0] == bloco._dados[0],
-                    self._dados[1] == bloco._dados[1]
-                   ])
+        return all([self._dados[0] == bloco._dados[0],
+                    self._dados[1] == bloco._dados[1]])
 
     # Override
     def le(self, arq: IO):
@@ -843,8 +1379,15 @@ class LeituraRelato(LeituraBlocos):
                  BlocoConvergenciaRelato(),
                  BlocoCMORelato(),
                  BlocoVolumeUtilReservatorioRelato(),
+                 BlocoDadosTermicasRelato(),
+                 BlocoDisponibilidadesTermicasRelato(),
+                 BlocoDadosMercadoRelato(),
+                 BlocoENAAcoplamentoREERelato(),
                  BlocoEnergiaArmazenadaREERelato(),
                  BlocoEnergiaArmazenadaSubsistemaRelato(),
+                 BlocoENAPreEstudoMensalREERelato(),
+                 BlocoENAPreEstudoMensalSubsistemaRelato(),
+                 BlocoENAPreEstudoSemanalREERelato(),
                  BlocoENAPreEstudoSemanalSubsistemaRelato(),
                  BlocoGeracaoTermicaSubsistemaRelato(),
                  BlocoDiasExcluidosSemanas()] +
